* ======= Experiment file ================================================
$ontext
 This file sets up and runs experiments on a model. It has a standard structure
 which is described below.

NB: 1) THE USER NEEDS TO SET (SECTION 3) AND IMPLEMENT THE SHOCKS (SECTION 5)
    2) THE USER SHOULD MAKE SURE THAT THE NAME OF THE OUTPUT FILEs - IN GDX -
       ARE THOSE DESIRED.
             DEFAULT NAMES ARE IMPOSED IN THE RESULT MODULES
                     - THESE CAN BE CHANGED BY THE USER.

 Structure
          1. Declare and Assign Simulation Set
          2. Define Result Parameters
          3. Setting up the sim shocks
                 3a. Declaring Parameters for Shocks
                 3b. Assigning Parameters for Shocks
          5. Runnin the experiments
                 5b. sim loop begins
                 5c. Implementing sim shocks
          6. Solve statement
          7. Storing results
          8. Terminating sim loop
          9. Exporting results
          10. Calculating percentage changes

The experiment code consists of a number of files; the relationships between
these files is illustrated below.

 glb_1_*.gms                                master programme file
     |
    .
     .
      .
       .
     | 16. POLICY EXPERIMENTS
     |
     |<----- glb1_expt_**.inc       Experiment files
             |
             |<----- glb1_resparm.inc     Declare results params
             |
             |<----- glb1_resassign.inc   Assigning results params
             |
             |<----- glb1_reslevel.inc    Levels results saved
             |
             |<----- glb1_resperc.inc     Proportionate results

$offtext

* ------- 1. Declare and Assign Simulation Set ---------------------------

* By including a "base case" in the SIM set a comparator is produced

SETS
* Sets for simulations

 sim          simulations
 sim1(sim)    simulations actually done

* Additional sets to control study specific experiments

 rlib(r)      regions that liberalise

  ;


* Convert Excel workbook data to GDX here
$CALL "GDXXRW i=data_expt_trad_lib.xls o=expt_in.gdx INDEX=LAYOUT!A4"

* Loading sets from GDX data file

$GDXIN expt_in.GDX

$LOAD sim sim1 rlib

$GDXIN

* Assigning membership to sim1 - default is all sim

* sim1(sim)    = YES ;

* Assigning set members by reference to other sets


* Additional sets to control study specific experiments


DISPLAY sim, sim1, rlib

 ;

* ------- 2. Define Result Parameters ------------------------------------
* This section defines the result parameter that are used to store model
* results between experiments and sims.

* ------------------- RESULTS IN LEVELS -----------------------------------

* Declaring parameters for levels (and proportionate change) results

$INCLUDE glb1_resparm_www.inc

* ------- 3. Setting up the sim shocks -----------------------------------

* ------- 3a. Declaring Parameters for Shocks ----------------------------

Parameter
* Standard parameters for tax instrument shocks
 TESIM(c,w,r,sim)      Export taxes on exported comm'y c from r to w
 TMSIM(w,c,r,sim)      Tariff rates on imported comm'y c from w by r
 TSSIM(c,r,sim)        Sales tax rate
 TXSIM(a,r,sim)        Indirect tax rate
 TYFSIM(f,r,sim)       Direct tax rate on factor income
 TYHSIM(h,r,sim)       Direct tax rate on households
 TFSIM(f,a,r,sim)      Tax rate on factor use

* Standard parameters for efficiency rate shocks
 ADXSIM(a,r,sim)       Shift parameter for CES production functions for QX in r
 ADVASIM(a,r,sim)      Shift parameter for CES production functions for QVA
 ADFDSIM(f,a,r,sim)    Shift parameter for factor and activity specific efficiency

* Standard parameters for factor demand and supply shocks
 FDSIM(f,a,r,sim)      Demand for factor f by activity a in r
 FSSIM(f,r,sim)        Supply of factor f in r

* Other parameters for shocks


* Shocks data parameter


  ;

* ------- 3b. Assigning Parameters for Shocks ----------------------------
$ontext
Parameter values for shocks can be entered in many ways, e.g.,

i) stored in Excel and read in via GDXXRW
ii) entered as tables/vectors in this file
iii) hard coded line by line when defining the shocks

The third option is used here but the choice ultimately depends on the
specific series of simuations.

$offtext

* ------ Defining the shock parameters
$ontext
$GDXIN expt_in.GDX



$GDXIN
$offtext

*---- 1. Setting tax rate shocks

* Tariff rates
 TMSIM(w,c,r,sim)           = TM0(w,c,r) ;

 TMSIM(w,c,r,"sim02")       = TM0(w,c,r) * 0.8 ;
 TMSIM(w,c,r,"sim03")       = TM0(w,c,r) * 0.6 ;
 TMSIM(w,c,r,"sim04")       = TM0(w,c,r) * 0.4 ;
 TMSIM(w,c,r,"sim05")       = TM0(w,c,r) * 0.2 ;
 TMSIM(w,c,r,"sim06")       = TM0(w,c,r) * 0.0 ;
 TMSIM(w,c,rlib,"sim07")    = TM0(w,c,rlib) * 0.5 ;
 TMSIM(w,c,rlib,"sim08")    = TM0(w,c,rlib) * 0.0 ;

* Export tax rates
 TESIM(c,w,r,sim)           = TE0(c,w,r) ;

 TESIM(c,w,r,"sim01")       = TE0(c,w,r) * 0.0 ;
 TESIM(c,w,r,"sim02")       = TE0(c,w,r) * 0.0 ;
 TESIM(c,w,r,"sim03")       = TE0(c,w,r) * 0.0 ;
 TESIM(c,w,r,"sim04")       = TE0(c,w,r) * 0.0 ;
 TESIM(c,w,r,"sim05")       = TE0(c,w,r) * 0.0 ;
 TESIM(c,w,r,"sim06")       = TE0(c,w,r) * 0.0 ;
 TESIM(c,w,r,"sim07")       = TE0(c,w,r) * 0.0 ;
 TESIM(c,w,r,"sim08")       = TE0(c,w,r) * 0.0 ;

* Factor Use Taxes
 TFSIM(f,a,r,sim)           = TF0(f,a,r) ;

* Household Income Taxes
 TYHSIM(h,r,sim)            = TYH0(h,r) ;

* Factor Income Taxes
 TYFSIM(f,r,sim)            = TYF0(f,r) ;

* Production tax rates
 TXSIM(a,r,sim)             = TX0(a,r) ;

* Sales tax rates
 TSSIM(c,r,sim)             = TS0(c,r) ;

*---- 2. Setting efficiency rate shocks

* Top level Hicks neutral efficiency parameter
 ADXSIM(a,r,sim)            = adx0(a,r) ;

* Aggregate value added Hicks neutral efficiency parameter
 ADVASIM(a,r,sim)           = adva0(a,r) ;

* Individual factor efficiency parameter
 ADFDSIM(f,a,r,sim)         = adfd0(f,a,r) ;


*---- 3. Setting factor supply shocks
* factor supply shocks
 FSSIM(f,r,sim)             = FS0(f,r) ;

* Displaying shock parameters

Display  TMSIM, TESIM, TFSIM, TYHSIM, TYFSIM, TXSIM, TSSIM,
         ADXSIM, ADVASIM, ADFDSIM,
         FSSIM
  ;

Execute_Unload  'glb1_shocks.gdx',
* Tax rate shocks
 TMSIM, TESIM, TFSIM, TYHSIM, TYFSIM, TXSIM, TSSIM,
 ADXSIM, ADVASIM, ADFDSIM,
 FDSIM, FSSIM

   ;


* ------- 5. Runnin the experiments ---------------------------------------

* ------- 5c. sim loop begins ---------------------------------------------

LOOP(sim1,

* ------- 5d. Implementing sim shocks -------------------------------------

*---- 1. Applying tax rate shocks

* Import duties

 tmb(w,c,r)    = TMSIM(w,c,r,sim1) ;

* Export taxes

 teb(c,w,r)    = TESIM(c,w,r,sim1) ;

* Factor Use taxes

 tfb(f,a,r)    = TFSIM(f,a,r,sim1) ;

* Household Income taxes

 tyhb(h,r)     = TYHSIM(h,r,sim1) ;

* Factor Income taxes

 tyfb(f,r)     = TYFSIM(f,r,sim1) ;

* Production taxes

 txb(a,r)      = TXSIM(a,r,sim1) ;

* Sales taxes

 tsb(c,r)      = TSSIM(c,r,sim1) ;

*---- 2. Applying efficiency rate shocks

* Top level Hicks neutral efficiency parameter
 adxb(a,r)     = ADXSIM(a,r,sim1) ;

* Aggregate value added Hicks neutral efficiency parameter
 advab(a,r)    = ADVASIM(a,r,sim1) ;

* Individual factor efficiency parameter
 adfdb(f,a,r)   = ADFDSIM(f,a,r,sim1) ;

*---- 3. Applying factor demand and supply shocks
* factor supply shocks
 FS.FX(f,r)     = FSSIM(f,r,sim1) ;


Display  tmb, teb, tfb, tyhb, tyfb, txb, tsb,
         adxb, advab, adfdb
 ;

* ------- 6. Solve statement ---------------------------------------------

 OPTION DECIMALS = 6 ;
 Options limrow=100,limcol=0;
* option iterlim = 25000 ;

 Solve globe1 Using MCP ;

* ------- 7. Storing results ---------------------------------------------

* Assigning levels results to the result parameters for all variables

$INCLUDE glb1_resassign_www.inc


* ------- 8. Terminating sim loop ----------------------------------------

 ) ;

* ------- 9. Exporting levels results ------------------------------------

$INCLUDE glb1_reslevel_www.inc

* ------- 10. Producing and Exporting Percent Change Results -------------

$INCLUDE glb1_resperc_www.inc

* ########### END OF EXPERIMENT FILE #####################################
